#include <cassert>
#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <cstring>

#define TASKNAME "connect"

typedef double real;

enum {OK, WA, PE, JE, NUM};
const char err [NUM] [4] = {"OK", "WA", "PE", "JE"};
const real eps = 1E-6;

FILE * fin, * fout, * fans;

void chkexit (const char * msg, int code)
{
 fprintf (stderr, "%s: %s\n", err[code], msg);
 exit (code);
}

const int MaxN = 200;
int x [MaxN], y [MaxN];
int c [MaxN];
int n;

#define sqr(x) ((x)*(x))
inline real rho (int x1, int y1, int x2, int y2)
{
 return sqrt (sqr (x2 - x1) + sqr (y2 - y1));
}

real answer (FILE * f, int mask)
{
 real r, s;
 int i, j, k, l, p;
 char ch;
 if (fscanf (f, " %lf", &r) != 1)
  chkexit ("No length given!", PE | mask);
 if (fscanf (f, " %d", &k) != 1)
  chkexit ("No number of edges given!", PE | mask);
 for (i = 0; i < n; i++)
  c[i] = i;
 s = 0.0;
 for (i = 0; i < k; i++)
 {
  if (fscanf (f, " %d %d", &j, &l) != 2)
   chkexit ("No edge given!", PE | mask);
  if (j == l)
   chkexit ("Edge is a loop!", WA | mask);
  if (j < 1 || j > n || l < 1 || l > n)
   printf ("%d %d %d\n", n, j, l),
   chkexit ("Edge ends not in range!", WA | mask);
  j--;
  l--;
  s += rho (x[j], y[j], x[l], y[l]);
  j = c[j];
  l = c[l];
  for (p = 0; p < n; p++)
   if (c[p] == j)
    c[p] = l;
 }
 if (fscanf (f, " %c", &ch) != EOF)
  chkexit ("Extra information at end of file!", PE | mask);
 for (i = 1; i < n; i++)
  if (c[i] != c[0])
   chkexit ("Some vertices are not connected!", WA | mask);
 if (fabs (r - s) > eps)
  chkexit ("Length does not match!", WA | mask);
 return s;
}

int main (int argc, char * argv [])
{
 real rc, rj, rd;
 int i;
 assert (argc >= 4);
 if ((fin = fopen (argv[1], "r")) == NULL) chkexit ("No input file!", JE);
 if ((fout = fopen (argv[2], "r")) == NULL) chkexit ("No output file!", PE);
 if ((fans = fopen (argv[3], "r")) == NULL) chkexit ("No answer file!", JE);
 fscanf (fin, " %d", &n);
 for (i = 0; i < n; i++)
  fscanf (fin, " %d %d", &x[i], &y[i]);
 rc = answer (fout, OK);
 rj = answer (fans, JE);
 rd = rc - rj;
 if (rd > eps)
  chkexit ("Contestant's answer is greater than jury's!", WA);
 if (rd < -eps)
  chkexit ("Jury's answer is greater than contestant's!", JE);
 chkexit ("Contestant and jury agree!", OK);
 fclose (fin);
 fclose (fout);
 fclose (fans);
}
